import tkinter
import os
from tkinter import *
from tkinter import colorchooser, filedialog
from PIL import Image, ImageTk

prev_x = None
prev_y = None
brush_color = "black"

def change_brush_size(new_size):
    global brush_size
    brush_size = int(new_size)

def change_brush_color(color):
    global brush_color
    brush_color = color

def paint(event):
    global prev_x, prev_y
    x, y = event.x, event.y
    if prev_x is not None and prev_y is not None:
        canvas.create_line(prev_x, prev_y, x, y, fill=brush_color, width=brush_size * 2)
    prev_x, prev_y = int(x), int(y)

def start_paint(event):
    global prev_x, prev_y
    prev_x, prev_y = event.x, event.y

def paint_bucket():
    canvas.config(bg=brush_color)

def import_image():
    file_path = filedialog.askopenfilename(filetypes=[("Image Files", "*.png;*.jpg;*.jpeg;*.gif")])
    if file_path:
        image = Image.open(file_path)
        resized_image = image.resize((canvas.winfo_width(), canvas.winfo_height()))
        canvas.image = ImageTk.PhotoImage(resized_image)
        canvas.create_image(0, 0, anchor="nw", image=canvas.image)

def switch_to_brush():
    change_brush_color("black")

def switch_to_eraser():
    change_brush_color("white")

def clear_canvas():
    canvas.delete("all")

def export_image():
    file_path = filedialog.asksaveasfilename(filetypes=[("PNG Image", "*.png"), ("JPEG Image", "*.jpg;*.jpeg"),
                                                        ("GIF Image", "*.gif"), ("PDF Document", "*.pdf")])
    if file_path:
        if file_path.lower().endswith(('.png', '.jpg', '.jpeg', '.gif')):
            ps_file_path = file_path + ".ps"  # Save the PostScript file path
            canvas.postscript(file=ps_file_path, colormode="color")
            img = Image.open(ps_file_path)
            img.save(file_path)
            img.close()
            os.remove(ps_file_path)  # Remove the temporary PostScript file
        elif file_path.lower().endswith('.pdf'):
            ps_file_path = file_path + ".ps"  # Save the PostScript file path
            canvas.postscript(file=ps_file_path, colormode="color")
            img = Image.open(ps_file_path)
            img.save(file_path, "PDF", resolution=100.0)
            img.close()
            os.remove(ps_file_path)  # Remove the temporary PostScript file

root = Tk()
root.title("Painter1")

toolbar = Frame(root, width=100, bg="gray")
toolbar.pack(side="left", fill="y")

brush_button = Button(toolbar, text="Brush", command=switch_to_brush)
brush_button.pack()

erase_button = Button(toolbar, text="Eraser", command=switch_to_eraser)
erase_button.pack()

brush_size_label = Button(toolbar, text="Brush Size", bg="gray")
brush_size_label.pack()

brush_size_slider = Scale(toolbar, from_=1, to=10, orient="vertical", length=150, command=change_brush_size)
brush_size_slider.set(5)
brush_size_slider.pack()

brush_color_button = Button(toolbar, text="Color", command=lambda: change_brush_color(colorchooser.askcolor()[1]))
brush_color_button.pack()

paint_bucket_button = Button(toolbar, text="Fill", command=paint_bucket)
paint_bucket_button.pack()

import_image_button = Button(toolbar, text="Import", command=import_image)
import_image_button.pack()

export_image_button = Button(toolbar, text="Export", command=export_image)
export_image_button.pack()

clear_canvas_button = Button(toolbar, text="Clear Canvas", command=clear_canvas)
clear_canvas_button.pack()

canvas = Canvas(root, width=800, height=600, bg="white")
canvas.pack()

canvas.bind("<B1-Motion>", paint)
canvas.bind("<ButtonPress-1>", start_paint)

brush_size = 5

root.mainloop()
